==> moodle-1.5-pgsql.tgz: moodle/lang/ja_utf8/lesson.php <==
<?PHP // $Id$ 
      // lesson.php - created with Moodle 1.6 development (2005052400)


$string['accesscontrol'] = 'アクセスコントロール';
$string['actionaftercorrectanswer'] = '正解後のアクション';
$string['addabranchtable'] = '分岐表を追加';
$string['addanendofbranch'] = '分岐終了を追加';
$string['addaquestionpage'] = '問題ページを追加';
$string['addcluster'] = 'クラスタを追加';
$string['addedabranchtable'] = '分岐表が追加されました。';
$string['addedanendofbranch'] = '分岐終了が追加されました。';
$string['addedaquestionpage'] = '問題ページが追加されました。';
$string['addedcluster'] = 'クラスタが追加されました。';
$string['addedendofcluster'] = 'クラスタ終了が追加されました。';
$string['addendofcluster'] = '終了クラスタを追加';
$string['answer'] = '選択肢';
$string['answeredcorrectly'] = '正常に解答されました。';
$string['answersfornumerical'] = '数字問題に対する解答は最大値および最小値の範囲内に入る必要があります。';
$string['arrangebuttonshorizontally'] = 'スライドショーで分岐ボタンを水平に配置しますか?';
$string['attempt'] = '受験: $a';
$string['attempts'] = '受験';
$string['available'] = 'レッスン公開';
$string['averagescore'] = '平均スコア';
$string['averagetime'] = '平均時間';
$string['backtreeview'] = 'ツリービューに戻る';
$string['branchtable'] = '分岐表';
$string['cancel'] = 'キャンセル';
$string['canretake'] = '$a の再受験';
$string['casesensitive'] = '大文字小文字の区別を行う';
$string['checkbranchtable'] = '分岐表の確認';
$string['checkedthisone'] = 'これをチェックする。';
$string['checknavigation'] = '動作を確認';
$string['checkquestion'] = '問題の確認';
$string['classstats'] = 'クラス統計';
$string['clicktopost'] = 'あなたの評点をハイスコア一覧に登録する場合は、ここをクリックしてください。';
$string['clusterjump'] = 'クラスタ内に隠された問題';
$string['clustertitle'] = 'クラスタ';
$string['comments'] = 'あなたのコメント';
$string['commentswithname'] = '$a->firstname {$a->lastname}のコメント';
$string['completed'] = '完了';
$string['confirmdeletionofthispage'] = 'このページを本当に削除してもよろしいですか?';
$string['congratulations'] = 'おめでとうございます - 最終レッスンに到達しました。';
$string['continue'] = '続ける';
$string['continuetoanswer'] = '続けて答えを変更する。';
$string['correctanswerjump'] = '正答のジャンプ先';
$string['correctanswerscore'] = '正答のスコア';
$string['correctresponse'] = '正答に対するレスポンス';
$string['customscoring'] = 'カスタムスコア';
$string['deadline'] = 'レッスン終了';
$string['defaultessayresponse'] = 'あなたの作文はコース教師によって評定されます。';
$string['deleteattempts'] = 'このレッスンの学生の受験を削除 ( ユーザID )';
$string['deletedpage'] = '削除済みページ';
$string['deleting'] = '削除中';
$string['deletingpage'] = 'ページの削除: $a';
$string['description'] = '説明';
$string['detailedstats'] = '統計詳細';
$string['didnotanswerquestion'] = 'この問題に答えていません。';
$string['displayhighscores'] = 'ハイスコアを表示';
$string['displayinleftmenu'] = '左メニューに表示しますか?';
$string['displayleftmenu'] = '左メニューを表示';
$string['displayofgrade'] = '評価を表示する ( 学生に対してのみ )';
$string['displayreview'] = 'レビューボタンを表示';
$string['displayscorewithoutessays'] = 'あなたのスコアは、 $a->score ( $a->grade 中 )です。';
$string['editlessonsettings'] = 'レッスンの更新';
$string['editpagecontent'] = 'ページコンテンツの編集';
$string['email'] = 'メール';
$string['emailallgradedessays'] = '全ての評定済み作文を<br />メール送信する';
$string['emailgradedessays'] = '評定済み作文をメール送信する';
$string['emailsuccess'] = 'メール送信完了';
$string['endofbranch'] = '分岐終了';
$string['endofclustertitle'] = 'クラスタ終了';
$string['endoflesson'] = 'レッスン終了';
$string['entername'] = 'ハイスコア一覧のニックネームを入力してください。';
$string['enterpassword'] = 'パスワードを入力してください:';
$string['eolstudentoutoftime'] = 'お知らせ: このレッスンの制限時間が終わりました。時間終了後に答えた内容は計算から除外されます。';
$string['eolstudentoutoftimenoanswers'] = 'あなたは問題に解答していません。このレッスンの評点は、0です。';
$string['essay'] = '作文';
$string['essayemailsubject'] = '$a 問題に対するあなたの評点';
$string['essays'] = '作文';
$string['essayscore'] = '作文スコア';
$string['fileformat'] = 'ファイルフォーマット';
$string['firstanswershould'] = '最初の答えは「正解」のページにジャンプする必要があります。';
$string['firstwrong'] = 'あなたのレスポンスが間違っていますので、残念ですが得点できませんでした。純粋な学習の楽しみのために、解答を続けますか ( 得点はできません ) ?';
$string['flowcontrol'] = 'フローコントロール';
$string['general'] = '一般設定';
$string['gobacktolesson'] = 'レッスンに戻る';
$string['grade'] = '評点';
$string['gradeessay'] = '作文問題の評定';
$string['gradeis'] = '評点は $a です';
$string['gradeoptions'] = '評定オプション';
$string['handlingofretakes'] = '再受験時の評定方法';
$string['havenotgradedyet'] = '未評定';
$string['here'] = ' ';
$string['highscore'] = 'ハイスコア';
$string['hightime'] = 'ハイタイム';
$string['importppt'] = 'PowerPointのインポート';
$string['importquestions'] = '問題のインポート';
$string['insertedpage'] = 'ページが挿入されました。';
$string['jump'] = 'ジャンプ';
$string['jumptsto'] = 'ジャンプ';
$string['leftduringtimed'] = 'あなたは時間制限のあるレッスンの途中で離れました。<br>レッスンを再スタートするためにクリックしてください。';
$string['leftduringtimednoretake'] = 'あなたは時間制限のあるレッスンの途中で離れました。<br>レッスンの再受験、継続はできません。';
$string['lesson'] = '$a レッスン';
$string['lessonclosed'] = 'このレッスンは $a に終了します。';
$string['lessondefault'] = 'この設定をデフォルトにする';
$string['lessonformating'] = 'レッスンフォーマット';
$string['lessonmenu'] = 'レッスンメニュー';
$string['lessonopen'] = 'このレッスンは $a に開始されます。';
$string['lessonstats'] = 'レッスン統計';
$string['loginfail'] = 'ログインに失敗しました、再度ログインしてください...';
$string['lowscore'] = 'ロースコア';
$string['lowtime'] = 'ロータイム';
$string['mainmenu'] = 'コースメニュー';
$string['matchesanswer'] = '正答';
$string['maxhighscores'] = 'ハイスコアの表示数';
$string['maximumnumberofanswersbranches'] = '答え/選択枝の最大数';
$string['maximumnumberofattempts'] = '受験の最大回数';
$string['maxtime'] = '制限時間 ( 分 )';
$string['maxtimewarning'] = 'レッスン終了まで $a 分です。';
$string['minimumnumberofquestions'] = '問題の最小数';
$string['modattempts'] = '学生のレビューを許可';
$string['modattemptsnoteacher'] = '学生レビューは学生のみに表示されます。';
$string['modulename'] = 'レッスン';
$string['modulenameplural'] = 'レッスン';
$string['movedpage'] = '移動済みページ';
$string['movepagehere'] = 'ページをここに移動する';
$string['moving'] = 'ページ移動: $a';
$string['movingtonextpage'] = '次ページに移動中';
$string['multianswer'] = '複数解答';
$string['multipleanswer'] = '複数解答';
$string['namereject'] = '申し訳ございません、あなたの名前はフィルタにより拒否されました。<br>別の名前をお使いください。';
$string['nextpage'] = '次ページ';
$string['noanswer'] = '解答がありません。';
$string['noattemptrecordsfound'] = '挑戦レコードが見つかりません: 評価無し';
$string['nocommentyet'] = 'コメントはありません。';
$string['nohighscores'] = 'ハイスコアはありません。';
$string['nooneansweredcorrectly'] = '正答者がいません。';
$string['nooneansweredthisquestion'] = 'この問題の解答者がいません。';
$string['noonecheckedthis'] = '未チェック';
$string['nooneenteredthis'] = '未入力';
$string['noretake'] = 'このレッスンは再受験できません。';
$string['normal'] = '通常 - レッスンパスに従う';
$string['notcompleted'] = '未了';
$string['notdefined'] = '未定義';
$string['nothighscore'] = 'あなたはトップ $a ハイスコアリストに入りませんでした。';
$string['notitle'] = 'タイトル無し';
$string['numberofcorrectanswers'] = '正答数: $a';
$string['numberofcorrectmatches'] = '正しいマッチ数: $a';
$string['numberofpagestoshow'] = 'ページ ( カード ) の表示数';
$string['numberofpagesviewed'] = 'ページ閲覧数: $a';
$string['ongoing'] = '進行中のスコアを表示';
$string['ongoingcustom'] = '現在、$a->currenthigh 点中 $a->score 点を取得しています。';
$string['ongoingnormal'] = 'あなたは $a->viewed の問題の中から $a->correct を正しく答えました。';
$string['or'] = 'または';
$string['other'] = 'その他';
$string['outof'] = '$a 中';
$string['outoftime'] = '時間切れ';
$string['overview'] = '概要';
$string['page'] = 'ページ: $a';
$string['pagecontents'] = 'ページ内容';
$string['pages'] = 'ページ';
$string['pagetitle'] = 'ページタイトル';
$string['password'] = 'パスワード';
$string['passwordprotectedlesson'] = '$a はパスワードで保護されたレッスンです。';
$string['pleasecheckoneanswer'] = '答えを選択してください';
$string['pleasecheckoneormoreanswers'] = '1つまたはそれ以上の答えを選択してください';
$string['pleaseenteryouranswerinthebox'] = '答えを入力してください';
$string['pleasematchtheabovepairs'] = '答えを選択してください';
$string['postsuccess'] = '正常に投稿されました。';
$string['practice'] = '練習レッスン';
$string['previouspage'] = '前ページ';
$string['question'] = '問題';
$string['questionoption'] = '問題';
$string['questiontype'] = '問題タイプ';
$string['randombranch'] = 'ランダム分岐ページ';
$string['randompageinbranch'] = '分岐内のランダム問題';
$string['rank'] = 'ランク';
$string['redisplaypage'] = '再表示';
$string['report'] = 'レポート';
$string['response'] = 'レスポンス';
$string['returnmainmenu'] = 'メインメニューに戻る';
$string['returntocourse'] = 'コースに戻る';
$string['reviewlesson'] = 'レッスンのレビュー';
$string['reviewquestionback'] = 'はい、もう一度受験します';
$string['reviewquestioncontinue'] = 'いいえ、次の問題に移ります';
$string['sanitycheckfailed'] = '正当性チェックが失敗しました: この受験は削除されました。';
$string['savechanges'] = '変更を保存';
$string['savechangesandeol'] = '全ての変更を保存してレッスンの最後に移動する。';
$string['savepage'] = 'ページを保存';
$string['score'] = 'スコア';
$string['scores'] = 'スコア';
$string['secondpluswrong'] = 'もう一度受験しますか?';
$string['showanunansweredpage'] = '未解答のページを表示';
$string['showanunseenpage'] = '未閲覧のページを表示';
$string['singleanswer'] = '単一解答';
$string['slideshow'] = 'スライドショー';
$string['slideshowbgcolor'] = 'スライドショーの背景色';
$string['slideshowheight'] = 'スライドショーの高さ';
$string['slideshowwidth'] = 'スライドショーの幅';
$string['startlesson'] = 'レッスンの開始';
$string['studentattemptlesson'] = '$a->lastname, $a->firstname の受験回数:  $a->attempt';
$string['studentoneminwarning'] = '警告: レッスンが終了するまで、残り時間1分またはそれ以下です。';
$string['studentoutoftime'] = 'お知らせ: このレッスンの制限時間が終わりました。最後の解答は時間終了後に行われましたので計算から除外されます。「続ける」ボタンを押してレッスンを終了してください。';
$string['studentresponse'] = '{$a} のレスポンス';
$string['teacherjumpwarning'] = 'このレッスンでは、$a->cluster ジャンプまたは $a->unseen ジャンプが使用されています。代わりに次のページへのジャンプが使用されます。学生としてログインして、これらのジャンプを確認してください。';
$string['teacherongoingwarning'] = '進行中のスコアは学生のみに表示されます。進行中のスコアをテストするには、学生としてログインしてください。';
$string['teachertimerwarning'] = 'タイマーは学生に対してのみ作動します。タイマーをテストするには、学生としてログインしてください。';
$string['thatsthecorrectanswer'] = '正しい答えです';
$string['thatsthewronganswer'] = '間違った答えです';
$string['thefollowingpagesjumptothispage'] = '下記のページは、このページにジャンプします。';
$string['thispage'] = 'このページ';
$string['timed'] = '時間制限';
$string['timeremaining'] = '残り時間';
$string['timetaken'] = '経過時間';
$string['topscorestitle'] = '$a->name レッスンのハイスコア上位 $a->maxhighscores 件';
$string['treeview'] = 'ツリービュー';
$string['unseenpageinbranch'] = '分岐内の未閲覧の問題';
$string['updatedpage'] = '更新失敗';
$string['updatefailed'] = '更新が失敗しました。';
$string['updatesuccess'] = '正常に更新されました。';
$string['useeditor'] = 'エディタを使用';
$string['usemaximum'] = '最大値';
$string['usemean'] = '平均値';
$string['usepassword'] = 'パスワードで保護';
$string['viewallpages'] = '全てのページを表示';
$string['viewgrades'] = '評点を表示';
$string['viewhighscores'] = 'ハイスコア一覧を表示';
$string['viewlessonstats'] = 'レッスン統計を表示';
$string['waitpostscore'] = 'お待ちください、ハイスコアを登録しています ...';
$string['welldone'] = 'よくできました!';
$string['whatdofirst'] = '最初に何をしますか?';
$string['wronganswerjump'] = '誤答のジャンプ先';
$string['wronganswerscore'] = '誤答のスコア';
$string['wrongresponse'] = '誤答に対するフィードバック';
$string['youhavereceived'] = 'この作文問題で、 out of $a->outof 点中 $a->score 点を取りました。';
$string['youhaveseen'] = 'あなたは既にこのレッスンを1ページ以上閲覧しました。<br />あなたが見た最後のページから始めますか?';
$string['youmadehighscore'] = 'あなたはトップ $a ハイスコアリストに入りました。';
$string['youranswer'] = 'あなたの答え';
$string['yourcurrentgradeis'] = '現在の成績は $a です。';
$string['yourgradeisnow'] = 'このレッスンに関するあなたの成績は $a に変更されました。';
$string['yourresponse'] = 'あなたのレスポンス';
$string['youshouldview'] = '少なくとも $a 回閲覧してください。';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/ja_utf8/lesson.php <==
<?PHP // $Id$ 
      // lesson.php - created with Moodle 1.6 development (2005060201)


$string['accesscontrol'] = 'アクセスコントロール';
$string['actionaftercorrectanswer'] = '正解後のアクション';
$string['addabranchtable'] = '分岐表を追加';
$string['addanendofbranch'] = '分岐終了を追加';
$string['addaquestionpage'] = '問題ページを追加';
$string['addcluster'] = 'クラスタを追加';
$string['addedabranchtable'] = '分岐表が追加されました。';
$string['addedanendofbranch'] = '分岐終了が追加されました。';
$string['addedaquestionpage'] = '問題ページが追加されました。';
$string['addedcluster'] = 'クラスタが追加されました。';
$string['addedendofcluster'] = 'クラスタ終了が追加されました。';
$string['addendofcluster'] = '終了クラスタを追加';
$string['answer'] = '選択肢';
$string['answeredcorrectly'] = '正常に解答されました。';
$string['answersfornumerical'] = '数字問題に対する解答は最大値および最小値の範囲内に入る必要があります。';
$string['arrangebuttonshorizontally'] = 'スライドショーで分岐ボタンを水平に配置しますか?';
$string['attempt'] = '受験: $a';
$string['attempts'] = '受験';
$string['available'] = 'レッスン公開';
$string['averagescore'] = '平均スコア';
$string['averagetime'] = '平均時間';
$string['backtreeview'] = 'ツリービューに戻る';
$string['branchtable'] = '分岐表';
$string['cancel'] = 'キャンセル';
$string['canretake'] = '$a の再受験';
$string['casesensitive'] = '大文字小文字の区別を行う';
$string['checkbranchtable'] = '分岐表の確認';
$string['checkedthisone'] = 'これをチェックする。';
$string['checknavigation'] = '動作を確認';
$string['checkquestion'] = '問題の確認';
$string['classstats'] = 'クラス統計';
$string['clicktopost'] = 'あなたの評点をハイスコア一覧に登録する場合は、ここをクリックしてください。';
$string['clusterjump'] = 'クラスタ内に隠された問題';
$string['clustertitle'] = 'クラスタ';
$string['comments'] = 'あなたのコメント';
$string['commentswithname'] = '$a->firstname {$a->lastname}のコメント';
$string['completed'] = '完了';
$string['confirmdeletionofthispage'] = 'このページを本当に削除してもよろしいですか?';
$string['congratulations'] = 'おめでとうございます - 最終レッスンに到達しました。';
$string['continue'] = '続ける';
$string['continuetoanswer'] = '続けて答えを変更する。';
$string['correctanswerjump'] = '正答のジャンプ先';
$string['correctanswerscore'] = '正答のスコア';
$string['correctresponse'] = '正答に対するレスポンス';
$string['customscoring'] = 'カスタムスコア';
$string['deadline'] = 'レッスン終了';
$string['defaultessayresponse'] = 'あなたの作文はコース教師によって評定されます。';
$string['deleteattempts'] = 'このレッスンの学生の受験を削除 ( ユーザID )';
$string['deletedpage'] = '削除済みページ';
$string['deleting'] = '削除中';
$string['deletingpage'] = 'ページの削除: $a';
$string['description'] = '説明';
$string['detailedstats'] = '統計詳細';
$string['didnotanswerquestion'] = 'この問題に答えていません。';
$string['displayhighscores'] = 'ハイスコアを表示';
$string['displayinleftmenu'] = '左メニューに表示しますか?';
$string['displayleftmenu'] = '左メニューを表示';
$string['displayofgrade'] = '評価を表示する ( 学生に対してのみ )';
$string['displayreview'] = 'レビューボタンを表示';
$string['displayscorewithessays'] = '自動評定によるあなたの評点は $a->score 分の $a->tempmaxgrade です。<br />作文問題 $a->essayquestions は評定され、後日あなたの最終評点に追加されます。<br /><br />作文問題を除くあなたの現在の評点は $a->score 分の $a->grade です。';
$string['displayscorewithoutessays'] = 'あなたのスコアは、 $a->score ( $a->grade 中 )です。';
$string['editlessonsettings'] = 'レッスンの更新';
$string['editpagecontent'] = 'ページコンテンツの編集';
$string['email'] = 'メール';
$string['emailallgradedessays'] = '全ての評定済み作文を<br />メール送信する';
$string['emailgradedessays'] = '評定済み作文をメール送信する';
$string['emailsuccess'] = 'メール送信完了';
$string['endofbranch'] = '分岐終了';
$string['endofclustertitle'] = 'クラスタ終了';
$string['endoflesson'] = 'レッスン終了';
$string['entername'] = 'ハイスコア一覧のニックネームを入力してください。';
$string['enterpassword'] = 'パスワードを入力してください:';
$string['eolstudentoutoftime'] = 'お知らせ: このレッスンの制限時間が終わりました。時間終了後に答えた内容は計算から除外されます。';
$string['eolstudentoutoftimenoanswers'] = 'あなたは問題に解答していません。このレッスンの評点は、0です。';
$string['essay'] = '作文';
$string['essayemailsubject'] = '$a 問題に対するあなたの評点';
$string['essays'] = '作文';
$string['essayscore'] = '作文スコア';
$string['fileformat'] = 'ファイルフォーマット';
$string['firstanswershould'] = '最初の答えは「正解」のページにジャンプする必要があります。';
$string['firstwrong'] = 'あなたのレスポンスが間違っていますので、残念ですが得点できませんでした。純粋な学習の楽しみのために、解答を続けますか ( 得点はできません ) ?';
$string['flowcontrol'] = 'フローコントロール';
$string['general'] = '一般設定';
$string['gobacktolesson'] = 'レッスンに戻る';
$string['grade'] = '評点';
$string['gradeessay'] = '作文問題の評定';
$string['gradeis'] = '評点は $a です';
$string['gradeoptions'] = '評定オプション';
$string['handlingofretakes'] = '再受験時の評定方法';
$string['havenotgradedyet'] = '未評定';
$string['here'] = ' ';
$string['highscore'] = 'ハイスコア';
$string['hightime'] = 'ハイタイム';
$string['importppt'] = 'PowerPointのインポート';
$string['importquestions'] = '問題のインポート';
$string['insertedpage'] = 'ページが挿入されました。';
$string['jump'] = 'ジャンプ';
$string['jumptsto'] = 'ジャンプ';
$string['leftduringtimed'] = 'あなたは時間制限のあるレッスンの途中で離れました。<br>レッスンを再スタートするためにクリックしてください。';
$string['leftduringtimednoretake'] = 'あなたは時間制限のあるレッスンの途中で離れました。<br>レッスンの再受験、継続はできません。';
$string['lesson'] = '$a レッスン';
$string['lessonclosed'] = 'このレッスンは $a に終了します。';
$string['lessondefault'] = 'この設定をデフォルトにする';
$string['lessonformating'] = 'レッスンフォーマット';
$string['lessonmenu'] = 'レッスンメニュー';
$string['lessonopen'] = 'このレッスンは $a に開始されます。';
$string['lessonstats'] = 'レッスン統計';
$string['loginfail'] = 'ログインに失敗しました、再度ログインしてください...';
$string['lowscore'] = 'ロースコア';
$string['lowtime'] = 'ロータイム';
$string['mainmenu'] = 'コースメニュー';
$string['matchesanswer'] = '正答';
$string['maxhighscores'] = 'ハイスコアの表示数';
$string['maximumnumberofanswersbranches'] = '答え/選択枝の最大数';
$string['maximumnumberofattempts'] = '受験の最大回数';
$string['maxtime'] = '制限時間 ( 分 )';
$string['maxtimewarning'] = 'レッスン終了まで $a 分です。';
$string['mediafile'] = 'メディアファイル';
$string['minimumnumberofquestions'] = '最小問題数';
$string['modattempts'] = '学生のレビューを許可';
$string['modattemptsnoteacher'] = '学生レビューは学生のみに表示されます。';
$string['modulename'] = 'レッスン';
$string['modulenameplural'] = 'レッスン';
$string['movedpage'] = '移動済みページ';
$string['movepagehere'] = 'ページをここに移動する';
$string['moving'] = 'ページ移動: $a';
$string['movingtonextpage'] = '次ページに移動中';
$string['multianswer'] = '複数解答';
$string['multipleanswer'] = '複数解答';
$string['namereject'] = '申し訳ございません、あなたの名前はフィルタにより拒否されました。<br>別の名前をお使いください。';
$string['nextpage'] = '次ページ';
$string['noanswer'] = '解答がありません。';
$string['noattemptrecordsfound'] = '挑戦レコードが見つかりません: 評価無し';
$string['nocommentyet'] = 'コメントはありません。';
$string['nohighscores'] = 'ハイスコアはありません。';
$string['nooneansweredcorrectly'] = '正答者がいません。';
$string['nooneansweredthisquestion'] = 'この問題の解答者がいません。';
$string['noonecheckedthis'] = '未チェック';
$string['nooneenteredthis'] = '未入力';
$string['noretake'] = 'このレッスンは再受験できません。';
$string['normal'] = '通常 - レッスンパスに従う';
$string['notcompleted'] = '未了';
$string['notdefined'] = '未定義';
$string['nothighscore'] = 'あなたはトップ $a ハイスコアリストに入りませんでした。';
$string['notitle'] = 'タイトル無し';
$string['numberofcorrectanswers'] = '正答数: $a';
$string['numberofcorrectmatches'] = '正しいマッチ数: $a';
$string['numberofpagestoshow'] = 'ページ ( カード ) の表示数';
$string['numberofpagesviewed'] = 'ページ閲覧数: $a';
$string['ongoing'] = '進行中のスコアを表示';
$string['ongoingcustom'] = '現在、$a->currenthigh 点中 $a->score 点を取得しています。';
$string['ongoingnormal'] = 'あなたは $a->viewed の問題の中から $a->correct を正しく答えました。';
$string['or'] = 'または';
$string['other'] = 'その他';
$string['outof'] = '$a 中';
$string['outoftime'] = '時間切れ';
$string['overview'] = '概要';
$string['page'] = 'ページ: $a';
$string['pagecontents'] = 'ページ内容';
$string['pages'] = 'ページ';
$string['pagetitle'] = 'ページタイトル';
$string['password'] = 'パスワード';
$string['passwordprotectedlesson'] = '$a はパスワードで保護されたレッスンです。';
$string['pleasecheckoneanswer'] = '答えを選択してください';
$string['pleasecheckoneormoreanswers'] = '1つまたはそれ以上の答えを選択してください';
$string['pleaseenteryouranswerinthebox'] = '答えを入力してください';
$string['pleasematchtheabovepairs'] = '答えを選択してください';
$string['postsuccess'] = '正常に投稿されました。';
$string['practice'] = '練習レッスン';
$string['previouspage'] = '前ページ';
$string['question'] = '問題';
$string['questionoption'] = '問題';
$string['questiontype'] = '問題タイプ';
$string['randombranch'] = 'ランダム分岐ページ';
$string['randompageinbranch'] = '分岐内のランダム問題';
$string['rank'] = 'ランク';
$string['redisplaypage'] = '再表示';
$string['report'] = 'レポート';
$string['response'] = 'レスポンス';
$string['returnmainmenu'] = 'メインメニューに戻る';
$string['returntocourse'] = 'コースに戻る';
$string['reviewlesson'] = 'レッスンのレビュー';
$string['reviewquestionback'] = 'はい、もう一度受験します';
$string['reviewquestioncontinue'] = 'いいえ、次の問題に移ります';
$string['sanitycheckfailed'] = '正当性チェックが失敗しました: この受験は削除されました。';
$string['savechanges'] = '変更を保存';
$string['savechangesandeol'] = '全ての変更を保存してレッスンの最後に移動する。';
$string['savepage'] = 'ページを保存';
$string['score'] = 'スコア';
$string['scores'] = 'スコア';
$string['secondpluswrong'] = 'もう一度受験しますか?';
$string['showanunansweredpage'] = '未解答のページを表示';
$string['showanunseenpage'] = '未閲覧のページを表示';
$string['singleanswer'] = '単一解答';
$string['slideshow'] = 'スライドショー';
$string['slideshowbgcolor'] = 'スライドショーの背景色';
$string['slideshowheight'] = 'スライドショーの高さ';
$string['slideshowwidth'] = 'スライドショーの幅';
$string['startlesson'] = 'レッスンの開始';
$string['studentattemptlesson'] = '$a->lastname, $a->firstname の受験回数:  $a->attempt';
$string['studentoneminwarning'] = '警告: レッスンが終了するまで、残り時間1分またはそれ以下です。';
$string['studentoutoftime'] = 'お知らせ: このレッスンの制限時間が終わりました。最後の解答は時間終了後に行われましたので計算から除外されます。「続ける」ボタンを押してレッスンを終了してください。';
$string['studentresponse'] = '{$a} のレスポンス';
$string['teacherjumpwarning'] = 'このレッスンでは、$a->cluster ジャンプまたは $a->unseen ジャンプが使用されています。代わりに次のページへのジャンプが使用されます。学生としてログインして、これらのジャンプを確認してください。';
$string['teacherongoingwarning'] = '進行中のスコアは学生のみに表示されます。進行中のスコアをテストするには、学生としてログインしてください。';
$string['teachertimerwarning'] = 'タイマーは学生に対してのみ作動します。タイマーをテストするには、学生としてログインしてください。';
$string['thatsthecorrectanswer'] = '正しい答えです';
$string['thatsthewronganswer'] = '間違った答えです';
$string['thefollowingpagesjumptothispage'] = '下記のページは、このページにジャンプします。';
$string['thispage'] = 'このページ';
$string['timed'] = '時間制限';
$string['timeremaining'] = '残り時間';
$string['timetaken'] = '経過時間';
$string['topscorestitle'] = '$a->name レッスンのハイスコア上位 $a->maxhighscores 件';
$string['treeview'] = 'ツリービュー';
$string['unseenpageinbranch'] = '分岐内の未閲覧の問題';
$string['updatedpage'] = '更新失敗';
$string['updatefailed'] = '更新が失敗しました。';
$string['updatesuccess'] = '正常に更新されました。';
$string['useeditor'] = 'エディタを使用';
$string['usemaximum'] = '最大点を使用';
$string['usemean'] = '平均点を使用';
$string['usepassword'] = 'パスワードで保護';
$string['viewallpages'] = '全てのページを表示';
$string['viewgrades'] = '評点を表示';
$string['viewhighscores'] = 'ハイスコア一覧を表示';
$string['viewlessonstats'] = 'レッスン統計を表示';
$string['waitpostscore'] = 'お待ちください、ハイスコアを登録しています ...';
$string['welldone'] = 'よくできました!';
$string['whatdofirst'] = '最初に何をしますか?';
$string['wronganswerjump'] = '誤答のジャンプ先';
$string['wronganswerscore'] = '誤答のスコア';
$string['wrongresponse'] = '誤答に対するフィードバック';
$string['youhavereceived'] = 'この作文問題で、 out of $a->outof 点中 $a->score 点を取りました。';
$string['youhaveseen'] = 'あなたは既にこのレッスンを1ページ以上閲覧しました。<br />あなたが見た最後のページから始めますか?';
$string['youmadehighscore'] = 'あなたはトップ $a ハイスコアリストに入りました。';
$string['youranswer'] = 'あなたの答え';
$string['yourcurrentgradeis'] = '現在の成績は $a です。';
$string['yourgradeisnow'] = 'このレッスンに関するあなたの成績は $a に変更されました。';
$string['yourresponse'] = 'あなたのレスポンス';
$string['youshouldview'] = '少なくとも $a 回閲覧してください。';

?>
